<?php

if(!class_exists('FTP_Page_Builder')){
	
	class FTP_Page_Builder{

		public function __construct(){
			add_action('init', array($this, 'init'));
			add_filter('body_class', array($this, 'set_body_class'));
			add_filter('kopa_page_builder_get_layouts', array('FTP_Page_Builder', 'set_layouts'));
			add_filter('kopa_page_builder_get_areas', array($this, 'set_areas'));
			add_filter('kopa_page_builder_get_section_fields', array($this, 'set_section_fields'));
			add_filter('kopa_page_builder_get_customize_fields', array($this, 'set_widget_fields'));
			add_action('wp_enqueue_scripts', array($this, 'enqueue_script'), 20);
		}

		public function init(){
			add_filter('friday_news_lite_is_override_default_template', array($this, 'active_pagebuilder'));
			add_action('friday_news_lite_load_template', array($this, 'load_template'));
			add_filter('friday_news_lite_get_header', array($this,'get_page_affix'));
			add_filter('friday_news_lite_get_footer', array($this,'get_page_affix'));
		}

		public function active_pagebuilder($is_override = false){
			if(is_page()){
				global $post;			

			    $current_layout = Kopa_Page_Builder::get_current_layout($post->ID);
			 	
			    if(!in_array($current_layout, array('', 'disable'))){
			 		$is_override = true;
			 	}
		 	}
		 	return $is_override;
		}

		public function load_template(){
			global $post;
			if(is_page()){
				$current_layout = Kopa_Page_Builder::get_current_layout($post->ID);

				if(!in_array($current_layout, array('', 'disable'))){
			 		$path = sprintf('page-builder/templates/%s', $current_layout); 		 		
					get_template_part( $path );
			 	}	
			}
		}

		public function get_page_affix($affix){
			if(is_page() && $this->active_pagebuilder()){
				global $post;
    			$current_layout = Kopa_Page_Builder::get_current_layout($post->ID);
    			if($current_layout == 'front-page-4') {
    				$affix = 'home-4';
    			}elseif($current_layout == 'front-page-3') {
    				$affix = 'home-3';
    			}
			}
			return $affix;
		}

		public function set_body_class($classes){
			if(is_page()){
				global $post;
				if( $current_layout = Kopa_Page_Builder::get_current_layout($post->ID) ){
					switch ($current_layout) {
						case 'contact-page':
							array_push($classes, 'kopa-contact');
							break;
					}
				}
			}

			return $classes;
		}

		public static function set_layouts(){
		    $layouts['disable'] = array(
		       'title' => esc_html__('-- Disable --', 'friday-news-lite')        
		    );

			$layouts['contact-page'] = array(
				'title'     => esc_html__('Contact Page', 'friday-news-lite'),
				'preview'   => get_template_directory_uri() . '/page-builder/images/layouts/contact-page.png',
				'customize' => array( 
		            'custom' => array(
						'title'  => esc_html__('Custom', 'friday-news-lite'),
						'params' => array(                  
		                    'css' => array(     
								'type'    => 'textarea',
								'title'   => esc_html__('CSS code', 'friday-news-lite'),
								'default' => '',
								'rows'    => 10,       
								'class'   => 'kpb-ui-textarea-guide-line',                        
		                    ),
		                )
		            ),	            
		        ),
		        'section' => array(
		        	'row-1' => array(
						'title'       => esc_html__('Row 1', 'friday-news-lite'),
						'description' => '',
						'grid'        => array(12),
						'customize'   => array(),        		
						'area'        => array(
		        			'area-1'
		        		)
		         	),
		         	'row-2' => array(
						'title'       => esc_html__('Row 2', 'friday-news-lite'),
						'grid'        => array(12),
						'description' => '',
						'customize'   => array(),        		
						'area'        => array(
		        			'area-2'        			
		        		)
		         	)	
		        )       
			);

		    return $layouts;
		}

		public function set_areas($areas){
			$areas['area-1']   = esc_html__('Area 1', 'friday-news-lite');
			$areas['area-2']   = esc_html__('Area 2', 'friday-news-lite');
			$areas['area-3']   = esc_html__('Area 3', 'friday-news-lite');
			$areas['area-4']   = esc_html__('Area 4', 'friday-news-lite');
			$areas['area-4-1'] = esc_html__('Area 4.1', 'friday-news-lite');
			$areas['area-4-2'] = esc_html__('Area 4.2', 'friday-news-lite');
			$areas['area-5']   = esc_html__('Area 5', 'friday-news-lite');
			$areas['area-6']   = esc_html__('Area 6', 'friday-news-lite');
			$areas['area-6-1']   = esc_html__('Area 6.1', 'friday-news-lite');
			$areas['area-6-2']   = esc_html__('Area 6.2', 'friday-news-lite');
			$areas['area-7']   = esc_html__('Area 7', 'friday-news-lite');

			return $areas;
		}

		public function set_section_fields($fields){
			$fields['outer']['title'] =  esc_html__('Outer', 'friday-news-lite');	
			$fields['outer']['params'] = array(
				'background-color' => array(		
					'type'    => 'color',
					'title'   => esc_html__('Background color', 'friday-news-lite'),
					'default' => '',								
				),
				'margin-top' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Margin top', 'friday-news-lite'),
					'default' => '',		
					'affix'   => 'px',						
				),
				'margin-bottom' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Margin bottom', 'friday-news-lite'),
					'default' => '',
					'affix'   => 'px',								
				),
				'padding-top' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Padding top', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',								
				),
				'padding-bottom' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Padding bottom', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',								
				),
				'custom' => array(
					'type'    => 'textarea',
					'title'   => esc_html__('CSS code', 'friday-news-lite'),
					'default' => '',
					'rows'    => 5,       
					'class'   => 'kpb-ui-textarea-guide-line',
					'help'    => esc_html__('Example: ID a {color: red; } ID: The ID of outer tag.', 'friday-news-lite'),
				),
			);	

			$fields['container']['title'] =  esc_html__('Inner', 'friday-news-lite');
			$fields['container']['params'] = array(
				'layout' => array(		
					'type'    => 'select',
					'title'   => esc_html__('Layout', 'friday-news-lite'),
					'default' => 'boxes',								
					'options' => array(
						'wide'  => esc_html__('Wide', 'friday-news-lite'),
						'boxes' => esc_html__('Boxes', 'friday-news-lite'),
					)
				),
				'margin-top' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Margin top', 'friday-news-lite'),
					'default' => '',		
					'affix'   => 'px',						
				),
				'margin-bottom' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Margin bottom', 'friday-news-lite'),
					'default' => '',
					'affix'   => 'px',								
				),
				'padding-top' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Padding top', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',								
				),
				'padding-bottom' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Padding bottom', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',								
				),	
				'custom' => array(
					'type'    => 'textarea',
					'title'   => esc_html__('CSS code', 'friday-news-lite'),
					'default' => '',
					'rows'    => 5,       
					'class'   => 'kpb-ui-textarea-guide-line',
					'help'    => esc_html__('Example: ID a {color: red; } ID: The ID of container tag.', 'friday-news-lite'),
				),
			);

			return $fields;
		}

		public function set_widget_fields($fields){
			$fields['title']['title'] =  esc_html__('Title', 'friday-news-lite');	
			$fields['title']['params'] = array(        
				'style' => array(		
					'type'    => 'select',
					'title'   => esc_html__('Style', 'friday-news-lite'),
					'default' => 'default',								
					'options' => array(
						'default'           => esc_html__("-- Default --", 'friday-news-lite'),				
						'breaking_news'     => esc_html__("Breaking news", 'friday-news-lite'),				
						'small-sub'         => esc_html__("Small and subtitle", 'friday-news-lite'),
						'small-sub-bold'    => esc_html__("Small and subtitle (line bottom bold)", 'friday-news-lite'),
						'medium'            => esc_html__("Medium - Line in right", 'friday-news-lite'),
						'big'               => esc_html__("Big - Line in left and right", 'friday-news-lite'),
						'bigest'            => esc_html__("Biggest", 'friday-news-lite'),
						'bigest_uncderline' => esc_html__("Biggest Underline", 'friday-news-lite')
					)
				),
				'subtitle' => array(
					'type'    => 'text',
					'title'   => esc_html__('Sub title', 'friday-news-lite'),
					'default' => '',
				)		
			);

			$fields['margin']['title']  =  esc_html__('Margin', 'friday-news-lite');	
			$fields['margin']['params'] = array(
				'top' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Top', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',	
				),		
				'bottom' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Bottom', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',	
				),	
				'left' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Left', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',	
				),	
				'right' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Right', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',	
				),
			);

			$fields['padding']['title']  =  esc_html__('Padding', 'friday-news-lite');	
			$fields['padding']['params'] = array(
				'top' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Top', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',	
				),		
				'bottom' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Bottom', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',	
				),	
				'left' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Left', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',	
				),	
				'right' => array(		
					'type'    => 'number',
					'title'   => esc_html__('Right', 'friday-news-lite'),
					'default' => '',	
					'affix'   => 'px',	
				),
			);

			$fields['custom']['title']  =  esc_html__('Custom CSS', 'friday-news-lite');	
			$fields['custom']['params'] = array(
				'css' => array(		
					'type'    => 'textarea',
					'title'   => esc_html__('CSS code', 'friday-news-lite'),
					'default' => '',
					'rows'    => 10,       
					'class'   => 'kpb-ui-textarea-guide-line', 
					'help'    => esc_html__('Example: <code>ID a {color: red; }</code> <br/> ID: The ID of this widget.', 'friday-news-lite'),
				),
			);

			return $fields;
		}

		public function enqueue_script(){
			if(is_page()){
				global $post;
				$current_layout = Kopa_Page_Builder::get_current_layout($post->ID);		

		        if(!empty($current_layout) && $current_layout != 'disable'){
		          
					$page_data             = Kopa_Page_Builder::get_current_layout_data($post->ID); 
					$layouts               = apply_filters('kopa_page_builder_get_layouts', array());             
					$layout_customize_data = Kopa_Page_Builder::get_layout_customize_data($post->ID, $current_layout);               
					$style                 = '';

		            foreach ($layouts as $layout_slug => $layout) {
		                if($layout_slug == $current_layout){
		                    $sections = $layout['section'];
		                    if(count($sections) > 0){
		                        foreach($sections as $section_slug => $section){
		                            if( $wrap = Kopa_Page_Builder::get_current_wrapper_data($post->ID, $layout_slug, $section_slug)){

		                            	//OUTTER
		                                	if(!empty($wrap['outer']['background-color'])){
		                                        $style .= sprintf('#friday-section-%s { background-color: %s; }', $section_slug, $wrap['outer']['background-color']);
		                                    }
		                                    
		                                    if(trim($wrap['outer']['margin-top']) != ''){
		                                        $style .= sprintf('#friday-section-%s { margin-top: %s%s; }', $section_slug, $wrap['outer']['margin-top'], 'px');
		                                    }

		                                    if(trim($wrap['outer']['margin-bottom']) != ''){
		                                        $style .= sprintf('#friday-section-%s { margin-bottom: %s%s; }', $section_slug, $wrap['outer']['margin-bottom'], 'px');
		                                    }

		                                    if(trim($wrap['outer']['padding-top']) != ''){
		                                        $style .= sprintf('#friday-section-%s { padding-top: %s%s; }', $section_slug, $wrap['outer']['padding-top'], 'px');
		                                    }

		                                    if(trim($wrap['outer']['padding-bottom']) != ''){
		                                        $style .= sprintf('#friday-section-%s { padding-bottom: %s%s; }', $section_slug, $wrap['outer']['padding-bottom'], 'px');
		                                    }

		                                    if(!empty($wrap['outer']['custom'])){
		                                        $style .= str_replace('ID', "#friday-section-{$section_slug}", $wrap['outer']['custom']);                               
		                                    }  

		                                //INNER ~ CONTAINER
										if(isset($wrap['container']['margin-top']) && trim($wrap['container']['margin-top']) != ''){
											$style .= sprintf('#friday-wrap-%s { margin-top: %s%s; }', $section_slug, $wrap['container']['margin-top'], 'px');
										}
										if(isset($wrap['container']['margin-bottom']) &&trim($wrap['container']['margin-bottom']) != ''){
											$style .= sprintf('#friday-wrap-%s { margin-bottom: %s%s; }', $section_slug, $wrap['container']['margin-bottom'], 'px');
										}
										if(isset($wrap['container']['padding-top']) &&trim($wrap['container']['padding-top']) != ''){
											$style .= sprintf('#friday-wrap-%s { padding-top: %s%s; }', $section_slug, $wrap['container']['padding-top'], 'px');
										}
										if(isset($wrap['container']['padding-bottom']) &&trim($wrap['container']['padding-bottom']) != ''){
											$style .= sprintf('#friday-wrap-%s { padding-bottom: %s%s; }', $section_slug, $wrap['container']['padding-bottom'], 'px');
										}

		                                if(!empty($wrap['container']['custom']))
		                                    $style .= str_replace('ID', "#friday-wrap-{$section_slug}", $wrap['container']['custom']);                                                        
		                            }               
		                        }
		                    }
		                }
		            }

		            if(!empty($page_data)){
		                foreach($page_data as $section_id => $section){
		                    if(!empty($section)){
		                        foreach ($section as $area_id => $area) {
		                            if(!empty($area)){
		                                foreach ($area as $widget_id => $widget) {
		                                    if($widget_data = get_post_meta($post->ID, $widget_id, true)){                                  
		                                        foreach(array('margin', 'padding') as $box_mode){
		                                            foreach(array('top', 'bottom', 'left', 'right') as $position){
		                                                if(isset($widget_data['customize'][$box_mode][$position])){
		                                                    if(trim($widget_data['customize'][$box_mode][$position]) != ''){
		                                                        $style .= sprintf('#%s.widget { %s-%s: %s%s; }', $widget_id, $box_mode, $position, $widget_data['customize'][$box_mode][$position], 'px');
		                                                    }
		                                                }                                           
		                                            }
		                                        }

		                                        if(isset($widget_data['customize']['custom']['css']) && !empty($widget_data['customize']['custom']['css'])){
		                                            $style .= str_replace('ID', "#{$widget_id}.widget", $widget_data['customize']['custom']['css']);
		                                        }                               
		                                    }
		                                }
		                            }
		                        }
		                    }
		                }
		            }

		            if(!empty($layout_customize_data)){
		                if(isset($layout_customize_data['custom']['css']) && !empty($layout_customize_data['custom']['css'])){                
		                    $style .= $layout_customize_data['custom']['css'];
		                }
		            }

		            if(!empty($style)){         
		                wp_add_inline_style('friday-style', $style);
		            }
		        }		        
			}	
		}	

		public static function print_before_section($current_layout, $section_slug){
			global $post;

			$out = '';

			ob_start();
			
			if($wrap = Kopa_Page_Builder::get_current_wrapper_data($post->ID, $current_layout, $section_slug)){		
				?>
					<section id="<?php echo "friday-section-{$section_slug}"; ?>" class="kopa-section">

							<?php if('boxes' == $wrap['container']['layout']): ?>
								<div id="<?php echo "friday-wrap-{$section_slug}"; ?>" class="wrapper">
							<?php else: ?>
								<div id="<?php echo "friday-wrap-{$section_slug}"; ?>">
							<?php endif;?>			

						<?php 
			}

			$out = ob_get_clean();

			return apply_filters('friday_print_before_section', $out, $current_layout, $section_slug);					
		}

		public static function print_after_section($current_layout, $section_slug){
			global $post;

			$out = '';

			ob_start();
			if($wrap = Kopa_Page_Builder::get_current_wrapper_data($post->ID, $current_layout, $section_slug)){
				?>					
						</div> <!-- container -->

				
					</section>
				<?php
			}

			$out = ob_get_clean();

			return apply_filters('friday_print_after_section', $out, $current_layout, $section_slug);		
		}

		public static function dynamic_area($post_id, $data){
			if($data){
				$index = 0;
				foreach($data as $widget_id => $widget){

					if($widget_data = get_post_meta($post_id, $widget_id, true)){
						$class_name = $widget['class_name'];	                                    

						if(class_exists($class_name)){
							$widget_extra_class = ( 0 == $index ) ? 'widget_first' : 'widget_other';
							$instance = $widget_data['widget'];

							$obj = new $class_name;

				            $obj->id = $widget_id;
				            $obj->number = rand(0, 9999);

				            $widget_wrap = array(
								'before_widget' => sprintf('<div id="%1$s" class="widget %2$s %3$s clearfix">', $obj->id, $obj->widget_options['classname'], $widget_extra_class),                                                
								'after_widget'  => '</div>',
								'before_title'  => '<h3 class="widget-title">',
								'after_title'   => '</h3>'
				            );

				            if(isset($widget_data['customize'])){
				            	$customize_data = $widget_data['customize'];
				            	switch ( $customize_data['title']['style'] ) {
				            		case 'breaking_news':
										$widget_wrap['before_title'] = '<div class="breaking-title"><i class="fa fa-newspaper-o"></i><span>';
										$widget_wrap['after_title']  = '</span></div>';
				            			break;
				            		case 'small-sub':		            							                
										$widget_wrap['before_title'] = '<h5 class="widget-title st-7"><span class="content">';

						                if ($sub_title = $customize_data['title']['subtitle']) {
						                    $widget_wrap['after_title'] = sprintf('</span><span>%s</span>', strip_tags($sub_title));
						                    $widget_wrap['after_title']  .= '<span class="divier"></span></h5>';
						                }else{
						                	$widget_wrap['after_title']  = '</span><span class="divier"></span></h5>';
						                }                
				            			break;
				            		case 'small-sub-bold':		            							                
										$widget_wrap['before_title'] = '<h5 class="widget-title st-5"><span class="content">';

						                if ($sub_title = $customize_data['title']['subtitle']) {
						                    $widget_wrap['after_title'] = sprintf('</span><span>%s</span>', strip_tags($sub_title));
						                    $widget_wrap['after_title']  .= '<span class="divier"></span></h5>';
						                }else{
						                	$widget_wrap['after_title']  = '</span><span class="divier"></span></h5>';
						                }                
				            			break;
				            		case 'medium':
										$widget_wrap['before_title'] = '<h2 class="widget-title st-1"><span class="content">';
										$widget_wrap['after_title']  = '</span><span class="divier"></span></h2>';
				            			break;
				            		case 'big':
										$widget_wrap['before_title'] = '<h2 class="widget-title st-4"><span class="content">';
										$widget_wrap['after_title']  = '</span></h2>';
				            			break;
				            		case 'bigest':
										$widget_wrap['before_title'] = '<h2 class="widget-title st-2"><span class="content">';
										$widget_wrap['after_title']  = '</span><span class="divier"></span></h2>';
				            			break;
				            		case 'bigest_uncderline':
										$widget_wrap['before_title'] = '<h2 class="widget-title st-10"><span class="content">';
										$widget_wrap['after_title']  = '</span></h2>';
				            			break;
				            	}
				            }

				            $obj->widget($widget_wrap, $instance);
						}	            
					}	
					$index++;	
				}
			}
		}

	}

	new FTP_Page_Builder();
}